// Copyright 2022 Datafuse Labs.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Behavior test suites.
mod behavior;

use behavior::BehaviorTest;

// All services must pass the behavior test suite.
mod fs;
mod memory;
mod s3;

pub fn init_logger() {
    let _ = env_logger::builder().is_test(true).try_init();
}
